==> web2py_1.99.7.orig.tar.gz: web2py-1.99.7.orig/applications/admin/languages/ja.py <==
# coding: utf8
{
'%Y-%m-%d %H:%M:%S': '%Y-%m-%d %H:%M:%S',
'%Y-%m-%d': '%Y-%m-%d',
'(requires internet access)': '(インターネットアクセスが必要)',
'(something like "it-it")': '(例: "it-it")',
'Abort': '中断',
'About application': 'アプリケーションについて',
'About': 'About',
'Additional code for your application': 'アプリケーションに必要な追加記述',
'Admin language': '管理画面の言語',
'administrative interface': '管理画面',
'Administrator Password:': '管理者パスワード:',
'and rename it:': 'ファイル名を変更:',
'appadmin': 'アプリ管理画面',
'application "%s" uninstalled': '"%s"アプリケーションが削除されました',
'application compiled': 'アプリケーションがコンパイルされました',
'Application name:': 'アプリケーション名:',
'Are you sure you want to delete plugin "%s"?': '"%s"プラグインを削除してもよろしいですか？',
'Are you sure you want to delete this object?': 'このオブジェクトを削除してもよろしいですか？',
'Are you sure you want to uninstall application "%s"?': '"%s"アプリケーションを削除してもよろしいですか？',
'arguments': '引数',
'ATTENTION: Login requires a secure (HTTPS) connection or running on localhost.': '注意: 安全(HTTPS)な接続でログインするかlocalhostで実行されている必要があります。',
'ATTENTION: TESTING IS NOT THREAD SAFE SO DO NOT PERFORM MULTIPLE TESTS CONCURRENTLY.': '注意: テストはスレッドセーフではないので複数のテストを同時に実行しないでください。',
'ATTENTION: you cannot edit the running application!': '注意: 実行中のアプリケーションは編集できません!',
'Available databases and tables': '利用可能なデータベースとテーブル一覧',
'back': '戻る',
'Basics': '基本情報',
'Begin': '開始',
'cache': 'cache',
'cannot upload file "%(filename)s"': '"%(filename)s"ファイルをアップロードできません',
'Change admin password': '管理者パスワード変更',
'check all': '全てを選択',
'Check for upgrades': '更新チェック',
'Checking for upgrades...': '更新を確認中...',
'Clean': '一時データ削除',
'Click row to expand traceback': '列をクリックしてトレースバックを展開',
'code': 'コード',
'collapse/expand all': '全て開閉する',
'Compile': 'コンパイル',
'compiled application removed': 'コンパイル済みのアプリケーションが削除されました',
'Controllers': 'コントローラ',
'controllers': 'コントローラ',
'Count': '回数',
'create file with filename:': 'ファイル名:',
'Create': '作成',
'created by': '作成者',
'crontab': 'crontab',
'currently running': '現在実行中',
'currently saved or': '現在保存されているデータ　または',
'database administration': 'データベース管理',
'db': 'db',
'defines tables': 'テーブル定義',
'delete all checked': '選択したデータを全て削除',
'delete plugin': 'プラグイン削除',
'Delete this file (you will be asked to confirm deletion)': 'ファイルの削除（確認画面が出ます）',
'Delete': '削除',
'Deploy on Google App Engine': 'Google App Engineにデプロイ',
'Deploy': 'デプロイ',
'design': 'デザイン',
'Detailed traceback description': '詳細なトレースバック内容',
'details': '詳細',
'direction: ltr': 'direction: ltr',
'Disable': '無効',
'docs': 'ドキュメント',
'download layouts': 'レイアウトのダウンロード',
'download plugins': 'プラグインのダウンロード',
'edit all': '全て編集',
'Edit application': 'アプリケーションを編集',
'edit views:': 'ビューの編集:',
'Edit': '編集',
'Editing file "%s"': '"%s"ファイルを編集中',
'Enable': '有効',
'Error logs for "%(app)s"': '"%(app)s"のエラーログ',
'Error snapshot': 'エラー発生箇所',
'Error ticket': 'エラーチケット',
'Error': 'エラー',
'Errors': 'エラー',
'Exception instance attributes': '例外インスタンス引数',
'exposes': '公開',
'exposes:': '公開:',
'extends': '継承',
'File': 'ファイル',
'files': 'ファイル',
'filter': 'フィルタ',
'Frames': 'フレーム',
'Functions with no doctests will result in [passed] tests.': 'doctestsのない関数は自動的にテストをパスします。',
'Generate': 'アプリ生成',
'Get from URL:': 'URLから取得:',
'go!': '実行!',
'Help': 'ヘルプ',
'If the report above contains a ticket number it indicates a failure in executing the controller, before any attempt to execute the doctests. This is usually due to an indentation error or an error outside function code.\nA green title indicates that all tests (if defined) passed. In this case test results are not shown.': 'もし上記のレポートにチケット番号が含まれる場合は、doctestを実行する前に、コントローラの実行で問題があったことを示します。これはインデントの問題やその関数の外部で問題があった場合に起きるが一般的です。\n緑色のタイトルは全てのテスト（もし定義されていれば）をパスしたことを示します。その場合、テスト結果は表示されません。',
'includes': 'インクルード',
'index': 'index',
'inspect attributes': '引数の検査',
'Install': 'インストール',
'Installed applications': 'アプリケーション一覧',
'Languages': '言語',
'languages': '言語',
'Last saved on:': '最終保存日時:',
'License for': 'License for',
'loading...': 'ロードしています...',
'locals': 'ローカル',
'Login to the Administrative Interface': '管理画面へログイン',
'Login': 'ログイン',
'Logout': 'ログアウト',
'Models': 'モデル',
'models': 'モデル',
'Modules': 'モジュール',
'modules': 'モジュール',
'New Application Wizard': '新規アプリケーション作成ウィザード',
'New application wizard': '新規アプリケーション作成ウィザード',
'new plugin installed': '新しいプラグインがインストールされました',
'New simple application': '新規アプリケーション',
'No databases in this application': 'このアプリケーションにはデータベースが存在しません',
'NO': 'いいえ',
'online designer': 'オンラインデザイナー',
'Overwrite installed app': 'アプリケーションを上書き',
'Pack all': 'パッケージ化',
'Pack compiled': 'コンパイルデータのパッケージ化',
'pack plugin': 'プラグインのパッケージ化',
'Peeking at file': 'ファイルを参照',
'plugin "%(plugin)s" deleted': '"%(plugin)s"プラグインは削除されました',
'Plugin "%s" in application': '"%s"プラグイン',
'Plugins': 'プラグイン',
'plugins': 'プラグイン',
'Powered by': 'Powered by',
'Reload routes': 'ルーティング再読み込み',
'Remove compiled': 'コンパイルデータの削除',
'request': 'リクエスト',
'response': 'レスポンス',
'restart': '最初からやり直し',
'restore': '復元',
'revert': '一つ前に戻す',
"Run tests in this file (to run all files, you may also use the button labelled 'test')": "このファイルのテストを実行(全てのファイルに対して実行する場合は、'テスト'というボタンを使用できます)",
'Save': '保存',
'Saved file hash:': '保存されたファイルハッシュ:',
'Searching:': '検索中:',
'session expired': 'セッションの有効期限が切れました',
'session': 'セッション',
'shell': 'shell',
'Site': 'サイト',
'skip to generate': 'スキップしてアプリ生成画面へ移動',
'Sorry, could not find mercurial installed': 'インストールされているmercurialが見つかりません',
'Start a new app': '新規アプリの作成',
'Start wizard': 'ウィザードの開始',
'state': 'state',
'Static files': '静的ファイル',
'static': '静的ファイル',
'Step': 'ステップ',
'test': 'テスト',
'Testing application': 'アプリケーションをテスト中',
'The application logic, each URL path is mapped in one exposed function in the controller': 'アプリケーションロジック、それぞれのURLパスはコントローラで公開されている各関数にマッピングされています',
'The data representation, define database tables and sets': 'データの表示方法, テーブルとセットの定義',
'The presentations layer, views are also known as templates': 'プレゼンテーション層、ビューはテンプレートとしても知られています',
'There are no controllers': 'コントローラがありません',
'There are no modules': 'モジュールがありません',
'There are no plugins': 'プラグインはありません',
'There are no translators, only default language is supported': '翻訳がないためデフォルト言語のみをサポートします',
'There are no views': 'ビューがありません',
'These files are served without processing, your images go here': 'これらのファイルは直接参照されます, ここに画像が入ります',
'Ticket ID': 'チケットID',
'to  previous version.': '前のバージョンへ戻す。',
'To create a plugin, name a file/folder plugin_[name]': 'ファイル名/フォルダ名 plugin_[名称]としてプラグインを作成してください',
'Traceback': 'トレースバック',
'Translation strings for the application': 'アプリケーションの翻訳文字列',
'Unable to download because:': '以下の理由でダウンロードできません:',
'uncheck all': '全ての選択を解除',
'Uninstall': 'アプリ削除',
'update all languages': '全ての言語を更新',
'Upload a package:': 'パッケージをアップロード:',
'Upload and install packed application': 'パッケージのアップロードとインストール',
'upload file:': 'ファイルをアップロード:',
'upload plugin file:': 'プラグインファイルをアップロード:',
'upload': 'アップロード',
'user': 'ユーザー',
'variables': '変数',
'Version': 'バージョン',
'Versioning': 'バージョン管理',
'Views': 'ビュー',
'views': 'ビュー',
'Web Framework': 'Web Framework',
'web2py is up to date': 'web2pyは最新です',
'web2py Recent Tweets': '最近のweb2pyTweets',
'YES': 'はい',
}

==> web2py_2.12.3.orig.tar.gz: web2py-2.12.3.orig/applications/admin/languages/ja.py <==
# -*- coding: utf-8 -*-
{
'!langcode!': 'ja-jp',
'!langname!': '日本語',
'%s %%{row} deleted': '%s rows deleted',
'%s %%{row} updated': '%s rows updated',
'%Y-%m-%d': '%Y-%m-%d',
'%Y-%m-%d %H:%M:%S': '%Y-%m-%d %H:%M:%S',
'(requires internet access)': '(インターネットアクセスが必要)',
'(something like "it-it")': '(例: "it-it")',
'@markmin\x01An error occured, please [[reload %s]] the page': 'An error occured, please [[reload %s]] the page',
'@markmin\x01Searching: **%s** %%{file}': '検索中: **%s** ファイル',
'Abort': '中断',
'About': 'About',
'About application': 'アプリケーションについて',
'Additional code for your application': 'アプリケーションに必要な追加記述',
'Admin language': '管理画面の言語',
'administrative interface': '管理画面',
'Administrator Password:': '管理者パスワード:',
'and rename it:': 'ファイル名を変更:',
'appadmin': 'アプリ管理画面',
'application "%s" uninstalled': '"%s"アプリケーションが削除されました',
'application compiled': 'アプリケーションがコンパイルされました',
'Application name:': 'アプリケーション名:',
'are not used': 'are not used',
'are not used yet': 'are not used yet',
'Are you sure you want to delete plugin "%s"?': '"%s"プラグインを削除してもよろしいですか？',
'Are you sure you want to delete this object?': 'このオブジェクトを削除してもよろしいですか？',
'Are you sure you want to uninstall application "%s"?': '"%s"アプリケーションを削除してもよろしいですか？',
'arguments': '引数',
'ATTENTION: Login requires a secure (HTTPS) connection or running on localhost.': '注意: 安全(HTTPS)な接続でログインするかlocalhostで実行されている必要があります。',
'ATTENTION: TESTING IS NOT THREAD SAFE SO DO NOT PERFORM MULTIPLE TESTS CONCURRENTLY.': '注意: テストはスレッドセーフではないので複数のテストを同時に実行しないでください。',
'ATTENTION: you cannot edit the running application!': '注意: 実行中のアプリケーションは編集できません!',
'Available databases and tables': '利用可能なデータベースとテーブル一覧',
'back': '戻る',
'Basics': '基本情報',
'Begin': '開始',
'cache': 'cache',
'cannot upload file "%(filename)s"': '"%(filename)s"ファイルをアップロードできません',
'Change admin password': '管理者パスワード変更',
'check all': '全てを選択',
'Check for upgrades': '更新チェック',
'Checking for upgrades...': '更新を確認中...',
'Clean': '一時データ削除',
'Click row to expand traceback': '列をクリックしてトレースバックを展開',
'code': 'コード',
'collapse/expand all': '全て開閉する',
'Compile': 'コンパイル',
'compiled application removed': 'コンパイル済みのアプリケーションが削除されました',
'Controllers': 'コントローラ',
'controllers': 'コントローラ',
'Count': '回数',
'Create': '作成',
'create file with filename:': 'ファイル名:',
'Create/Upload': 'Create/Upload',
'created by': '作成者',
'crontab': 'crontab',
'currently running': '現在実行中',
'currently saved or': '現在保存されているデータ　または',
'database administration': 'データベース管理',
'db': 'db',
'Debug': 'Debug',
'defines tables': 'テーブル定義',
'Delete': '削除',
'delete all checked': '選択したデータを全て削除',
'delete plugin': 'プラグイン削除',
'Delete this file (you will be asked to confirm deletion)': 'ファイルの削除（確認画面が出ます）',
'Deploy': 'デプロイ',
'Deploy on Google App Engine': 'Google App Engineにデプロイ',
'design': 'デザイン',
'Detailed traceback description': '詳細なトレースバック内容',
'details': '詳細',
'direction: ltr': 'direction: ltr',
'Disable': '無効',
'docs': 'ドキュメント',
'download layouts': 'レイアウトのダウンロード',
'Download layouts from repository': 'Download layouts from repository',
'download plugins': 'プラグインのダウンロード',
'Download plugins from repository': 'Download plugins from repository',
'Edit': '編集',
'edit all': '全て編集',
'Edit application': 'アプリケーションを編集',
'edit views:': 'ビューの編集:',
'Editing file "%s"': '"%s"ファイルを編集中',
'Enable': '有効',
'Error': 'エラー',
'Error logs for "%(app)s"': '"%(app)s"のエラーログ',
'Error snapshot': 'エラー発生箇所',
'Error ticket': 'エラーチケット',
'Errors': 'エラー',
'Exception instance attributes': '例外インスタンス引数',
'exposes': '公開',
'exposes:': '公開:',
'extends': '継承',
'File': 'ファイル',
'filter': 'フィルタ',
'Frames': 'フレーム',
'Functions with no doctests will result in [passed] tests.': 'doctestsのない関数は自動的にテストをパスします。',
'Generate': 'アプリ生成',
'Get from URL:': 'URLから取得:',
'go!': '実行!',
'graph model': 'graph model',
'Help': 'ヘルプ',
'If the report above contains a ticket number it indicates a failure in executing the controller, before any attempt to execute the doctests. This is usually due to an indentation error or an error outside function code.\nA green title indicates that all tests (if defined) passed. In this case test results are not shown.': 'もし上記のレポートにチケット番号が含まれる場合は、doctestを実行する前に、コントローラの実行で問題があったことを示します。これはインデントの問題やその関数の外部で問題があった場合に起きるが一般的です。\n緑色のタイトルは全てのテスト（もし定義されていれば）をパスしたことを示します。その場合、テスト結果は表示されません。',
'includes': 'インクルード',
'index': 'index',
'inspect attributes': '引数の検査',
'Install': 'インストール',
'Installed applications': 'アプリケーション一覧',
'languages': '言語',
'Languages': '言語',
'Last saved on:': '最終保存日時:',
'License for': 'License for',
'loading...': 'ロードしています...',
'locals': 'ローカル',
'Login': 'ログイン',
'Login to the Administrative Interface': '管理画面へログイン',
'Logout': 'ログアウト',
'models': 'モデル',
'Models': 'モデル',
'Modules': 'モジュール',
'modules': 'モジュール',
'New Application Wizard': '新規アプリケーション作成ウィザード',
'New application wizard': '新規アプリケーション作成ウィザード',
'new plugin installed': '新しいプラグインがインストールされました',
'New simple application': '新規アプリケーション',
'NO': 'いいえ',
'No databases in this application': 'このアプリケーションにはデータベースが存在しません',
'no package selected': 'no package selected',
'online designer': 'オンラインデザイナー',
'or alternatively': 'or alternatively',
'Overwrite installed app': 'アプリケーションを上書き',
'Pack all': 'パッケージ化',
'Pack compiled': 'コンパイルデータのパッケージ化',
'pack plugin': 'プラグインのパッケージ化',
'Peeking at file': 'ファイルを参照',
'plugin "%(plugin)s" deleted': '"%(plugin)s"プラグインは削除されました',
'Plugin "%s" in application': '"%s"プラグイン',
'Plugins': 'プラグイン',
'plugins': 'プラグイン',
'Plural-Forms:': 'Plural-Forms:',
'Powered by': 'Powered by',
'Private files': 'Private files',
'private files': 'private files',
'Reload routes': 'ルーティング再読み込み',
'Remove compiled': 'コンパイルデータの削除',
'request': 'リクエスト',
'response': 'レスポンス',
'restart': '最初からやり直し',
'restore': '復元',
'revert': '一つ前に戻す',
"Run tests in this file (to run all files, you may also use the button labelled 'test')": "このファイルのテストを実行(全てのファイルに対して実行する場合は、'テスト'というボタンを使用できます)",
'Save': '保存',
'Saved file hash:': '保存されたファイルハッシュ:',
'session': 'セッション',
'session expired': 'セッションの有効期限が切れました',
'shell': 'shell',
'Site': 'サイト',
'skip to generate': 'スキップしてアプリ生成画面へ移動',
'Sorry, could not find mercurial installed': 'インストールされているmercurialが見つかりません',
'Start a new app': '新規アプリの作成',
'Start wizard': 'ウィザードの開始',
'state': 'state',
'static': '静的ファイル',
'Static': 'Static',
'Static files': '静的ファイル',
'Step': 'ステップ',
'test': 'テスト',
'Testing application': 'アプリケーションをテスト中',
'The application logic, each URL path is mapped in one exposed function in the controller': 'アプリケーションロジック、それぞれのURLパスはコントローラで公開されている各関数にマッピングされています',
'The data representation, define database tables and sets': 'データの表示方法, テーブルとセットの定義',
'The presentations layer, views are also known as templates': 'プレゼンテーション層、ビューはテンプレートとしても知られています',
'There are no controllers': 'コントローラがありません',
'There are no modules': 'モジュールがありません',
'There are no plugins': 'プラグインはありません',
'There are no private files': 'There are no private files',
'There are no translators, only default language is supported': '翻訳がないためデフォルト言語のみをサポートします',
'There are no views': 'ビューがありません',
'These files are not served, they are only available from within your app': 'These files are not served, they are only available from within your app',
'These files are served without processing, your images go here': 'これらのファイルは直接参照されます, ここに画像が入ります',
'Ticket ID': 'チケットID',
'to  previous version.': '前のバージョンへ戻す。',
'To create a plugin, name a file/folder plugin_[name]': 'ファイル名/フォルダ名 plugin_[名称]としてプラグインを作成してください',
'Traceback': 'トレースバック',
'Translation strings for the application': 'アプリケーションの翻訳文字列',
'Unable to download because:': '以下の理由でダウンロードできません:',
'uncheck all': '全ての選択を解除',
'Uninstall': 'アプリ削除',
'update all languages': '全ての言語を更新',
'upload': 'アップロード',
'Upload': 'Upload',
'Upload a package:': 'パッケージをアップロード:',
'Upload and install packed application': 'パッケージのアップロードとインストール',
'upload file:': 'ファイルをアップロード:',
'upload plugin file:': 'プラグインファイルをアップロード:',
'user': 'ユーザー',
'variables': '変数',
'Version': 'バージョン',
'Versioning': 'バージョン管理',
'Views': 'ビュー',
'views': 'ビュー',
'Web Framework': 'Web Framework',
'web2py is up to date': 'web2pyは最新です',
'web2py Recent Tweets': '最近のweb2pyTweets',
'YES': 'はい',
}
